@@ -6,12 +6,13 @@ from pymongo.collection import Collection
 from pymongo.database import Database
 from bson.objectid import ObjectId
 from inflection import pluralize
+from threading import Timer
 from .utils import default_db
 from .encoder import Encoder
 from .query import IDQuery, ListQuery, SingleQuery, OptionalSingleQuery
 
 
-@jsonclass
+@jsonclass(abstract=True)
 class BaseMongoObject(ORMObject):
     """BaseMongoObject is a `JSONObject` subclass for defining your business
     models with MongoDB. A `BaseMongoObject` class represents a MongoDB
@@ -37,12 +38,16 @@ class BaseMongoObject(ORMObject):
 
     @classmethod
     def __loaded__(cls: type[T], class_: type[T]) -> None:
-        cls._sync_db_settings(class_)
+        if not class_.config.abstract:
+            timer = Timer(0.1, cls._sync_db_settings, [class_])
+            timer.start()
 
     @classmethod
     def _sync_db_settings(cls: type[T], class_: type[T]) -> None:
         fields = get_fields(class_)
         coll = class_.collection()
+        print("coll index info", coll.name)
+        print(coll.index_information())
         for field in fields:
             name = field.db_field_name
             index = field.fdesc.index
@@ -50,18 +55,15 @@ class BaseMongoObject(ORMObject):
             required = field.fdesc.required
             if unique:
                 if required:
-                    iname = coll.create_index(name, unique=True)
-                    print("created index", iname, coll.name)
+                    coll.create_index(name, name=f'{name}_1', unique=True)
                 else:
-                    iname = coll.create_index(name, unique=True, sparse=True)
-                    print("created index", iname, coll.name)
+                    coll.create_index(name, name=f'{name}_1', unique=True,
+                                      sparse=True)
             elif index:
                 if required:
-                    iname = coll.create_index(name)
-                    print("created index", iname, coll.name)
+                    coll.create_index(name, name=f'{name}_1')
                 else:
-                    iname = coll.create_index(name, sparse=True)
-                    print("created index", iname, coll.name)
+                    coll.create_index(name, name=f'{name}_1', sparse=True)
             else:
                 pass
                 coll.drop_index
