@@ -1,32 +1,29 @@
 from __future__ import annotations
-from typing import TypeVar, Type, TYPE_CHECKING
-from jsonclasses import (Field, FieldType, FieldStorage,
-                         collection_argument_type_to_types)
+from typing import cast, TYPE_CHECKING
+from jsonclasses import (Field, FieldType, FieldStorage, resolve_types)
 from inflection import camelize
 if TYPE_CHECKING:
-    from .mongo_object import MongoObject
-    T = TypeVar('T', bound=MongoObject)
+    from .base_mongo_object import BaseMongoObject
 
 
 class Coder():
 
     def is_id_field(self, field: Field) -> bool:
-        return field.field_name == 'id'
+        return field.fdesc.primary
 
     def is_instance_field(self, field: Field) -> bool:
-        return (field.field_types.field_description.field_type ==
-                FieldType.INSTANCE)
+        return field.fdesc.field_type == FieldType.INSTANCE
 
     def is_list_field(self, field: Field) -> bool:
-        return field.field_types.field_description.field_type == FieldType.LIST
+        return field.fdesc.field_type == FieldType.LIST
 
     def is_foreign_key_storage(self, field: Field) -> bool:
-        return (field.field_types.field_description.field_storage ==
-                FieldStorage.FOREIGN_KEY)
+        field_storage = field.fdesc.field_storage
+        return field_storage == FieldStorage.FOREIGN_KEY
 
     def is_local_key_storage(self, field: Field) -> bool:
-        return (field.field_types.field_description.field_storage ==
-                FieldStorage.LOCAL_KEY)
+        field_storage = field.fdesc.field_storage
+        return field_storage == FieldStorage.LOCAL_KEY
 
     def is_foreign_key_reference_field(self, field: Field) -> bool:
         return (self.is_instance_field(field) and
@@ -44,18 +41,23 @@ class Coder():
         return self.is_list_field(field) and self.is_local_key_storage(field)
 
     def is_join_table_field(self, field: Field) -> bool:
-        return field.field_types.field_description.use_join_table is True
+        return field.field_types.fdesc.use_join_table is True
 
-    def other_field_class_for_list_instance_type(
-        self, field: Field, sibling: Type[T]
-    ) -> Type[T]:
-        item_types = collection_argument_type_to_types(
-            field.field_types.field_description.list_item_types, sibling)
-        return item_types.field_description.instance_types
+    def list_instance_type(self,
+                           field: Field,
+                           sibling: type[BaseMongoObject]
+                           ) -> type[BaseMongoObject]:
+        from .mongo_object import MongoObject
+        fd = field.field_types.fdesc
+        item_types = resolve_types(fd.raw_item_types, sibling)
+        item_fd = item_types.fdesc
+        return cast(type[MongoObject], item_fd.instance_types)
 
-    def join_table_name(
-        self, cls_a: Type[T], field_a: str, cls_b: Type[T], field_b: str
-    ) -> str:
+    def join_table_name(self,
+                        cls_a: type[BaseMongoObject],
+                        field_a: str,
+                        cls_b: type[BaseMongoObject],
+                        field_b: str) -> str:
         ca = cls_a.collection().name + camelize(field_a).lower()
         cb = cls_b.collection().name + camelize(field_b).lower()
         return ca + cb if ca < cb else cb + ca
